@@ -9,11 +9,12 @@
 #' @param to numeric time to plot to. Only relevant if \code{qi = "Hazard Rate"}.
 #' @param title the plot's main title.
 #' @param smoother what type of smoothing line to use to summarize the plotted coefficient.
-#' @param spalette colour palette for use in \code{qi = "Hazard Rate"}. Default palette is \code{"Set1"}. See \code{\link{scale_colour_brewer}}.
-#' @param leg.name name of the stratified hazard rates legend. Only relevant if \code{qi = "Hazard Rate"}.
+#' @param spalette colour palette for when there are multiple sets of comparisons to plot. Default palette is \code{"Set1"}. See \code{\link{scale_colour_brewer}}.
+#' @param legend specifies what type of legend to include (if applicable). The default is \code{legend = "legend"}. To hide the legend use \code{legend = FALSE}. See the \code{\link{discrete_scale}} for more details.
+#' @param leg.name name of the legend (if applicable).
 #' @param lcolour character string colour of the smoothing line. The default is hexadecimal colour \code{lcolour = '#2B8CBE'}. Only relevant if \code{qi = "First Difference"}.
-#' @param lsize size of the smoothing line. Default is 2. See \code{\link{ggplot2}}.
-#' @param pcolour character string colour of the simulated points for relative hazards. Default is hexadecimal colour \code{pcolour = '#A6CEE3'}. Only relevant if \code{qi = "First Difference"}.
+#' @param lsize size of the smoothing line. Default is 1. See \code{\link{ggplot2}}.
+#' @param pcolour character string colour of the simulated points or ribbons (when there are not multiple sets of simulations). Default is hexadecimal colour \code{pcolour = '#A6CEE3'}.
 #' @param psize size of the plotted simulation points. Default is \code{psize = 1}. See \code{\link{ggplot2}}.
 #' @param alpha point alpha (e.g. transparency) for the points or ribbons. Default is \code{alpha = 0.1}. See \code{\link{ggplot2}}.
 #' @param ribbons logical specifies whether or not to use summary ribbons of the simulations rather than plotting every simulation value as a point. If \code{ribbons = TRUE} a plot will be created with shaded areas ('ribbons') for the minimum and maximum simulation values (i.e. the middle interval set with \code{qi} in \code{\link{coxsimLinear}}) as well as the central 50 percent of this area. It also plots a line for the median value of the full area, so values in \code{smoother} are ignored. One of the key advantages of using ribbons rather than points is that it creates plots with smaller file sizes.
@@ -42,7 +43,6 @@
 #' #						Xj = seq(1237, 1600, by = 2), spin = TRUE)
 #' # simGG(Sim1)
 #' 
-#' ## dontrun
 #' # Simulate and plot Hazard Rate for stafcder variable
 #' # Sim2 <- coxsimLinear(M1, b = "stafcder", nsim = 100,
 #' #						qi = "Hazard Rate", Xj = c(1237, 1600))
@@ -63,12 +63,15 @@
 #'
 #' Carpenter, Daniel P. 2002. ''Groups, the Media, Agency Waiting Costs, and FDA Drug Approval.'' American Journal of Political Science 46(3): 490-505.
 
-simGG.simlinear <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL, title = NULL, smoother = "auto", spalette = "Set1", leg.name = "", lcolour = "#2B8CBE", lsize = 2, pcolour = "#A6CEE3", psize = 1, alpha = 0.1, ribbons = FALSE, ...)
+simGG.simlinear <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL, title = NULL, smoother = "auto", spalette = "Set1", legend = "legend", leg.name = "", lcolour = "#2B8CBE", lsize = 1, pcolour = "#A6CEE3", psize = 1, alpha = 0.1, ribbons = FALSE, ...)
 {
 	Time <- HRate <- HRValue <- Xj <- QI <- Lower50 <- Upper50 <- Min <- Max <- Median <- NULL
 	if (!inherits(obj, "simlinear")){
     	stop("must be a simlinear object")
     }
+	if (isTRUE(ribbons) & smoother != "auto"){
+	  message("The smoother argument is ignored if ribbons = TRUE. Central tendency summarised with the median.")
+	}
     # Find quantity of interest
     qi <- class(obj)[[2]]  
     
@@ -99,18 +102,18 @@ simGG.simlinear <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NUL
 				geom_point(alpha = I(alpha), size = psize) +
 				geom_smooth(method = smoother, size = lsize, se = FALSE) +
 				xlab(xlab) + ylab(ylab) +
-				scale_colour_brewer(palette = spalette, name = leg.name) +
+				scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
 				ggtitle(title) +
-				guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+				#guides(colour = guide_legend(override.aes = list(alpha = 1))) +
 				theme_bw(base_size = 15)
     	} else if (is.null(obj$Strata)){
 	      	ggplot(obj, aes(Time, HRate, colour = factor(HRValue))) +
 	        	geom_point(shape = 21, alpha = I(alpha), size = psize) +
 		        geom_smooth(method = smoother, size = lsize, se = FALSE) +
-		        scale_colour_brewer(palette = spalette, name = leg.name) +
+		        scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
 		        xlab(xlab) + ylab(ylab) +
 		        ggtitle(title) +
-		        guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+		        #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
 		        theme_bw(base_size = 15)
 			}
 		} else if (qi == "First Difference"){
@@ -120,7 +123,7 @@ simGG.simlinear <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NUL
 		        geom_hline(aes(yintercept = 0), linetype = "dotted") +
 		        xlab(xlab) + ylab(ylab) +
 		        ggtitle(title) +
-		        guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+		        #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
 		        theme_bw(base_size = 15)
 		} else if (qi == "Hazard Ratio" | qi == "Relative Hazard"){
 		ggplot(obj, aes(Xj, QI)) +
@@ -129,7 +132,7 @@ simGG.simlinear <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NUL
 	        geom_hline(aes(yintercept = 1), linetype = "dotted") +
 	        xlab(xlab) + ylab(ylab) +
 	        ggtitle(title) +
-	        guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+	        #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
 	        theme_bw(base_size = 15)
 		}
 	}
@@ -145,10 +148,10 @@ simGG.simlinear <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NUL
 				geom_ribbon(aes(ymin = Min, ymax = Max), alpha = alpha, linetype = 0) +
 				facet_grid(. ~ Strata) +
 				xlab(xlab) + ylab(ylab) +
-		        scale_colour_brewer(palette = spalette, name = leg.name) +
-		        scale_fill_brewer(palette = spalette, name = leg.name) +
+		        scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
+		        scale_fill_brewer(palette = spalette, name = leg.name, guide = legend) +
 				ggtitle(title) +
-		        guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+		        #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
 				theme_bw(base_size = 15)
     	} else if (is.null(obj$Strata)){
 			obj <- MinMaxLines(df = obj, hr = TRUE)
@@ -156,11 +159,11 @@ simGG.simlinear <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NUL
 		        geom_line(size = lsize) +
 				geom_ribbon(aes(ymin = Lower50, ymax = Upper50), alpha = alpha, linetype = 0) +
 				geom_ribbon(aes(ymin = Min, ymax = Max), alpha = alpha, linetype = 0) +
-		        scale_colour_brewer(palette = spalette, name = leg.name) +
-		        scale_fill_brewer(palette = spalette, name = leg.name) +
+		        scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
+		        scale_fill_brewer(palette = spalette, name = leg.name, guide = legend) +
 		        xlab(xlab) + ylab(ylab) +
 		        ggtitle(title) +
-		        guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+		        #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
 		        theme_bw(base_size = 15)
 		}
 		} else if (qi == "First Difference"){
@@ -172,7 +175,7 @@ simGG.simlinear <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NUL
 		        geom_hline(aes(yintercept = 0), linetype = "dotted") +
 		        xlab(xlab) + ylab(ylab) +
 		        ggtitle(title) +
-		        guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+		        #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
 		        theme_bw(base_size = 15)
 		} else if (qi == "Hazard Ratio" | qi == "Relative Hazard"){
 			obj <- MinMaxLines(df = obj)
@@ -183,7 +186,7 @@ simGG.simlinear <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NUL
 	        	geom_hline(aes(yintercept = 1), linetype = "dotted") +
 		        xlab(xlab) + ylab(ylab) +
 		        ggtitle(title) +
-		        guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+		        #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
 		        theme_bw(base_size = 15)
 		}
 		)
